@@ -18,6 +18,9 @@ from sky_api_client.entity import relationship  # noqa: F401
 from sky_api_client.entity import table_entry  # noqa: F401
 from sky_api_client.entity import webhook_subscription  # noqa: F401
 from sky_api_client.entity import constituent_address  # noqa: F401
+from sky_api_client.entity import constituent_custom_field  # noqa: F401
+from sky_api_client.entity import constituent_education  # noqa: F401
 from sky_api_client.entity import constituent_email_address  # noqa: F401
 from sky_api_client.entity import constituent_online_presence  # noqa: F401
 from sky_api_client.entity import constituent_phone  # noqa: F401
+from sky_api_client.entity import constituent_relationship  # noqa: F401
